// Copyright (c) 2015-present Mattermost, Inc. All Rights Reserved.
// See LICENSE.txt for license information.

import React from 'react';
import {shallow, ShallowWrapper} from 'enzyme';

import Menu from 'components/widgets/menu/menu';

import ViewPinnedPosts from './view_pinned_posts';

describe('components/ChannelHeaderDropdown/MenuItem.ViewPinnedPosts', () => {
    const baseProps = {
        channel: {
            id: 'channel_id',
        },
        hasPinnedPosts: true,
        actions: {
            closeRightHandSide: jest.fn(),
            showPinnedPosts: jest.fn(),
        },
    };

    it('should match snapshot', () => {
        const wrapper: ShallowWrapper<any, any, ViewPinnedPosts> = shallow(<ViewPinnedPosts {...baseProps}/>);
        expect(wrapper).toMatchSnapshot();
    });

    it('should runs closeRightHandSide function if has any pinned posts', () => {
        const wrapper: ShallowWrapper<any, any, ViewPinnedPosts> = shallow(<ViewPinnedPosts {...baseProps}/>);

        wrapper.find(Menu.ItemAction).simulate('click', {
            preventDefault: jest.fn(),
        });

        expect(baseProps.actions.closeRightHandSide).toHaveBeenCalled();
    });

    it('should runs showPinnedPosts function if has not pinned posts', () => {
        const props = {
            ...baseProps,
            hasPinnedPosts: false,
        };
        const wrapper: ShallowWrapper<any, any, ViewPinnedPosts> = shallow(<ViewPinnedPosts {...props}/>);

        wrapper.find(Menu.ItemAction).simulate('click', {
            preventDefault: jest.fn(),
        });

        expect(baseProps.actions.showPinnedPosts).toHaveBeenCalled();
    });
});
